tools

package
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2026 License: MIT Imports: 38 Imported by: 0

Documentation

Overview

Package tools provides tool registration and handlers for all Google Workspace services.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FilterTools

func FilterTools(s *mcpserver.MCPServer, cfg server.Config)

FilterTools removes tools from the server based on tier, capability, and read-only settings. It is called after RegisterAllTools.

func RegisterAllTools

func RegisterAllTools(s *mcpserver.MCPServer, cfg server.Config)

RegisterAllTools registers tools for all enabled services based on config. If cfg.Tools is empty, all services are registered.

func RegisterAppScriptTools

func RegisterAppScriptTools(s *mcpserver.MCPServer, _ server.Config)

RegisterAppScriptTools registers all Apps Script tools with the MCP server.

func RegisterAuthTools

func RegisterAuthTools(s *mcpserver.MCPServer)

RegisterAuthTools registers the auth_start meta-tool. It is filtered out when MCP_ENABLE_OAUTH21=true.

func RegisterCalendarTools

func RegisterCalendarTools(s *mcpserver.MCPServer, _ server.Config)

RegisterCalendarTools registers all Calendar tools with the MCP server.

func RegisterChatTools

func RegisterChatTools(s *mcpserver.MCPServer, _ server.Config)

RegisterChatTools registers all Chat tools with the MCP server.

func RegisterCommentTools

func RegisterCommentTools(s *mcpserver.MCPServer, getClient httpClientFunc, service, appName, fileIDParam string)

RegisterCommentTools registers 4 comment management tools for a Google Workspace app. service is the MCP name prefix (docs, sheets, slides). appName is the human app type (document, spreadsheet, presentation). fileIDParam is the parameter name for the file ID (document_id, spreadsheet_id, presentation_id).

func RegisterContactsTools

func RegisterContactsTools(s *mcpserver.MCPServer, _ server.Config)

RegisterContactsTools registers all Contacts tools with the MCP server.

func RegisterDocsTools

func RegisterDocsTools(s *mcpserver.MCPServer, _ server.Config)

RegisterDocsTools registers all Docs tools with the MCP server.

func RegisterDriveTools

func RegisterDriveTools(s *mcpserver.MCPServer, _ server.Config)

RegisterDriveTools registers all Drive tools with the MCP server.

func RegisterFormsTools

func RegisterFormsTools(s *mcpserver.MCPServer, _ server.Config)

RegisterFormsTools registers all Forms tools with the MCP server.

func RegisterGmailTools

func RegisterGmailTools(s *mcpserver.MCPServer, _ server.Config)

RegisterGmailTools registers all Gmail tools with the MCP server.

func RegisterSearchTools

func RegisterSearchTools(s *mcpserver.MCPServer, _ server.Config)

RegisterSearchTools registers all Search tools with the MCP server.

func RegisterSheetsTools

func RegisterSheetsTools(s *mcpserver.MCPServer, _ server.Config)

RegisterSheetsTools registers all Sheets tools with the MCP server.

func RegisterSlidesTools

func RegisterSlidesTools(s *mcpserver.MCPServer, _ server.Config)

RegisterSlidesTools registers all Slides tools with the MCP server.

func RegisterTasksTools

func RegisterTasksTools(s *mcpserver.MCPServer, _ server.Config)

RegisterTasksTools registers all Tasks tools with the MCP server.

func RegisterTool

func RegisterTool(s *mcpserver.MCPServer, tool mcp.Tool, handler mcpserver.ToolHandlerFunc)

RegisterTool is a helper that wraps mcp.NewTool + server.AddTool.

Types

This section is empty.

Jump to