Documentation
¶
Overview ¶
Package tools provides tool registration and handlers for all Google Workspace services.
Index ¶
- func FilterTools(s *mcpserver.MCPServer, cfg server.Config)
- func RegisterAllTools(s *mcpserver.MCPServer, cfg server.Config)
- func RegisterAppScriptTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterAuthTools(s *mcpserver.MCPServer)
- func RegisterCalendarTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterChatTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterCommentTools(s *mcpserver.MCPServer, getClient httpClientFunc, ...)
- func RegisterContactsTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterDocsTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterDriveTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterFormsTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterGmailTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterSearchTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterSheetsTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterSlidesTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterTasksTools(s *mcpserver.MCPServer, _ server.Config)
- func RegisterTool(s *mcpserver.MCPServer, tool mcp.Tool, handler mcpserver.ToolHandlerFunc)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FilterTools ¶
FilterTools removes tools from the server based on tier, capability, and read-only settings. It is called after RegisterAllTools.
func RegisterAllTools ¶
RegisterAllTools registers tools for all enabled services based on config. If cfg.Tools is empty, all services are registered.
func RegisterAppScriptTools ¶
RegisterAppScriptTools registers all Apps Script tools with the MCP server.
func RegisterAuthTools ¶
RegisterAuthTools registers the auth_start meta-tool. It is filtered out when MCP_ENABLE_OAUTH21=true.
func RegisterCalendarTools ¶
RegisterCalendarTools registers all Calendar tools with the MCP server.
func RegisterChatTools ¶
RegisterChatTools registers all Chat tools with the MCP server.
func RegisterCommentTools ¶
func RegisterCommentTools(s *mcpserver.MCPServer, getClient httpClientFunc, service, appName, fileIDParam string)
RegisterCommentTools registers 4 comment management tools for a Google Workspace app. service is the MCP name prefix (docs, sheets, slides). appName is the human app type (document, spreadsheet, presentation). fileIDParam is the parameter name for the file ID (document_id, spreadsheet_id, presentation_id).
func RegisterContactsTools ¶
RegisterContactsTools registers all Contacts tools with the MCP server.
func RegisterDocsTools ¶
RegisterDocsTools registers all Docs tools with the MCP server.
func RegisterDriveTools ¶
RegisterDriveTools registers all Drive tools with the MCP server.
func RegisterFormsTools ¶
RegisterFormsTools registers all Forms tools with the MCP server.
func RegisterGmailTools ¶
RegisterGmailTools registers all Gmail tools with the MCP server.
func RegisterSearchTools ¶
RegisterSearchTools registers all Search tools with the MCP server.
func RegisterSheetsTools ¶
RegisterSheetsTools registers all Sheets tools with the MCP server.
func RegisterSlidesTools ¶
RegisterSlidesTools registers all Slides tools with the MCP server.
func RegisterTasksTools ¶
RegisterTasksTools registers all Tasks tools with the MCP server.
func RegisterTool ¶
RegisterTool is a helper that wraps mcp.NewTool + server.AddTool.
Types ¶
This section is empty.